import Image from "next/image";
import { notFound } from "next/navigation";

import axios from "axios";

import { ShopLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import FeaturesCarousel from "@/components/sections/services/features-carousel";
import LinkRequestAFieldVisit from "@/components/sections/services/link-request-a-field-visit";
import Packages from "@/components/sections/services/packages";
import ServiceDetails from "@/components/sections/services/service-details";
import ServiceImages from "@/components/sections/services/service-images";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { BaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { Suspense } from "react";


async function ServicesNamePage({
	params,
}: {
	params: Promise<{ locale: Locale; id: string }>;
}) {
	const { locale, id } = await params;

	const { data: service } = await axios.get(`${BaseUrl}/services/${id}/details`);
	console.log("service:", service);
	const findCurrentService = service.data;

	if (!findCurrentService) return notFound();

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/services",
			label: {
				en: "Services",
				ar: "الخدمات",
			},
		},
		{
			href: `/services/${id}`,
			label: {
				en: findCurrentService?.name_en,
				ar: findCurrentService?.name_ar,
			},
		},
	];

	return (
		<LocomotiveScrollWrapper>
			<main className="block overflow-hidden text-gray-700">
				<Header />
				<Suspense fallback={<ShopLoadingSkeleton locale={locale} />}>
					<PageBreadcrump
						backgroundUrl={"/heros/service-name.png"}
						locale={locale}
						subtitle={{
							en: "Bin Taleb Company",
							ar: "شركة بن طالب",
						}}
						title={{
							en: findCurrentService?.name_en,
							ar: findCurrentService?.name_ar,
						}}
						breadcrumbItems={breadcrumbItems}
					/>
					<div className="relative">
						<div className="z-10 mx-auto flex w-full max-w-10xl flex-col items-center gap-8 p-5 md:flex-row md:p-14">
							<div className="flex-[50%]">
								<ServiceDetails locale={locale} service={findCurrentService} />
							</div>
							<div className="flex-[50%]">
								<ServiceImages
									thumbnail={findCurrentService?.thumbnail}
									images={findCurrentService?.images}
								/>
							</div>
						</div>
						<Image
							src={"/background-service-details.png"}
							alt=""
							fill
							className="pointer-events-none -z-10"
							objectFit="cover"
						/>
					</div>

					<div className="relative mx-auto max-w-10xl px-5 py-20 md:px-12">
						<LinkRequestAFieldVisit locale={locale} />

						<FeaturesCarousel locale={locale} features={findCurrentService?.features} />

						<Packages locale={locale} packages={findCurrentService?.packages} />

						{/*<ProductsForService
							lang={locale}
							products={findCurrentService.products}
						/>						

						<FeaturedFeatures locale={locale} />

						<FAQSServices locale={locale} />*/}
					</div>

					<div className="">
						<Footer />
					</div>
				</Suspense>
			</main>
		</LocomotiveScrollWrapper>
	);
}

export default ServicesNamePage;
